# radpy
Robust Angular Diameters in Python

## add how to use the package, how to install, descriptions of the fitting routine etc. 

## can put the comments I already made in my jupyter notebook in here
